==> flink-core-1.0.0-sources.jar: org/apache/flink/api/common/io/compression/DeflateInflaterInputStreamFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.api.common.io.compression;

import org.apache.flink.annotation.Internal;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;
import java.util.Collections;
import java.util.zip.InflaterInputStream;

/**
 * Factory for input streams that decompress the "deflate" compression format.
 */
@Internal
public class DeflateInflaterInputStreamFactory implements InflaterInputStreamFactory<InflaterInputStream> {

	private static DeflateInflaterInputStreamFactory INSTANCE = null;

	public static DeflateInflaterInputStreamFactory getInstance() {
		if (INSTANCE == null) {
			INSTANCE = new DeflateInflaterInputStreamFactory();
		}
		return INSTANCE;
	}

	@Override
	public InflaterInputStream create(InputStream in) throws IOException {
		return new InflaterInputStream(in);
	}

	@Override
	public Collection<String> getCommonFileExtensions() {
		return Collections.singleton("deflate");
	}
}

==> flink-core-1.7.2-sources.jar: org/apache/flink/api/common/io/compression/DeflateInflaterInputStreamFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.io.compression;

import org.apache.flink.annotation.Internal;

import java.io.IOException;
import java.io.InputStream;
import java.util.Collection;
import java.util.Collections;
import java.util.zip.InflaterInputStream;

/**
 * Factory for input streams that decompress the "deflate" compression format.
 */
@Internal
public class DeflateInflaterInputStreamFactory implements InflaterInputStreamFactory<InflaterInputStream> {

	private static final DeflateInflaterInputStreamFactory INSTANCE = new DeflateInflaterInputStreamFactory();

	public static DeflateInflaterInputStreamFactory getInstance() {
		return INSTANCE;
	}

	@Override
	public InflaterInputStream create(InputStream in) throws IOException {
		return new InflaterInputStream(in);
	}

	@Override
	public Collection<String> getCommonFileExtensions() {
		return Collections.singleton("deflate");
	}
}
